@@ -1,20 +1,16 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Text Plain File Upload Input Transformations plugin for phpMyAdmin
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage TextFileUpload
  */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Plugins\Transformations\Input;
 
 use PhpMyAdmin\Plugins\Transformations\Abs\TextFileUploadTransformationsPlugin;
 
 /**
  * Handles the input text file upload transformation for text plain.
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage TextFileUpload
  */
 // @codingStandardsIgnoreLine
 class Text_Plain_FileUpload extends TextFileUploadTransformationsPlugin
@@ -26,7 +22,7 @@ class Text_Plain_FileUpload extends TextFileUploadTransformationsPlugin
      */
     public static function getMIMEType()
     {
-        return "Text";
+        return 'Text';
     }
 
     /**
@@ -36,6 +32,6 @@ class Text_Plain_FileUpload extends TextFileUploadTransformationsPlugin
      */
     public static function getMIMESubtype()
     {
-        return "Plain";
+        return 'Plain';
     }
 }
